import { world, system } from "@minecraft/server";

const MAX_HEARTS = 75;
const FOODS_PER_HEART = 7;

// Subscribe to the itemCompleteUse event
world.afterEvents.itemCompleteUse.subscribe((event) => {
    const player = event.source;
    const item = event.itemStack;

// Check if the item is food
if (!item && !item?.hasComponent('food') && !item.typeId.startsWith('minecraft:')) return;

    let newFoods = player.getDynamicProperty("newFoods") ?? 0;
    let currentHearts = player.getDynamicProperty("currentHearts") ?? 10; // Start with 10 hearts (20 health)

    // Check if this is a new food
    if (!player.hasTag(`eaten_${item.typeId}`)) {
        newFoods++;
        player.setDynamicProperty("newFoods", newFoods);
        player.addTag(`eaten_${item.typeId}`);

        player.sendMessage(`You ate a new food: ${item.typeId}`);

        // Check if player has eaten enough new foods for a heart
        if (newFoods >= FOODS_PER_HEART) {
            if (currentHearts < MAX_HEARTS) {
                currentHearts++;
                player.setDynamicProperty("currentHearts", currentHearts);
                player.setDynamicProperty("newFoods", 0);

                // Update player's max health using the event
                player.triggerEvent(`hearts:health_up${currentHearts * 2}`);

                player.sendMessage(`You gained one heart! New max health: ${currentHearts} hearts`);
            } else {
                player.sendMessage(`You've reached the maximum of ${MAX_HEARTS} hearts!`);
            }
        } else {
            player.sendMessage(`You need to eat ${FOODS_PER_HEART - newFoods} more new foods to gain a heart.`);
        }
    }
});

// Optional: Command to check current hearts and new foods eaten
world.beforeEvents.chatSend.subscribe(e => {
    const player = e.sender;
    const mess = e.message
    const chat = mess.split(' ');
    const line = chat[0];
    const prefix = `!`
    if (line.startsWith(prefix)) {
        switch (line) {
            case prefix+`hearts`:
                const currentHearts = player.getDynamicProperty("currentHearts") ?? 10;
                const newFoods = player.getDynamicProperty("newFoods") ?? 0;
                player.sendMessage(`You currently have ${currentHearts} hearts and have eaten ${newFoods} new foods.`);
                break;
        }
    }
    for (const pre of prefix) {
        if (mess.startsWith(pre)) {
          e.cancel = true;
          return;
        }}
});